@@ -1,6 +1,6 @@
 from .api_client import ApiClient
-from .auth import (BearerAuth, OAuth2AuthorizationCodeAuth,
-                   OAuth2ClientCredentialsAuth, OAuth20AccessTokenAuth)
+from .auth import (BearerAuth, OAuth2AccessTokenAuth,
+                   OAuth2AuthorizationCodeAuth, OAuth2ClientCredentialsAuth)
 from .authorization_request import AuthorizationRequest, PkceUtils
 from .client import OAuth2Client
 from .client_authentication import (ClientSecretBasic, ClientSecretJWT,
